@@ -1,7 +1,7 @@
 /** @file termgenerator_internal.cc
  * @brief TermGenerator class internals
  */
-/* Copyright (C) 2007,2010,2011 Olly Betts
+/* Copyright (C) 2007,2010,2011,2012 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,14 +37,6 @@ using namespace std;
 
 namespace Xapian {
 
-// Put a limit on the size of terms to help prevent the index being bloated
-// by useless junk terms.
-static const unsigned int MAX_PROB_TERM_LENGTH = 64;
-// FIXME: threshold is currently in bytes of UTF-8 representation, not unicode
-// characters - what actually makes most sense here?
-
-// FIXME: Add API to allow control of how stemming is used?
-
 inline bool
 U_isupper(unsigned ch) {
     return (ch < 128 && C_isupper((unsigned char)ch));
@@ -172,7 +164,7 @@ TermGenerator::Internal::index_text(Utf8Iterator itor, termcount wdf_inc,
 		const string & cjk = CJK::get_cjk(itor);
 		for (CJKTokenIterator tk(cjk); tk != CJKTokenIterator(); ++tk) {
 		    const string & cjk_token = *tk;
-		    if (cjk_token.size() > MAX_PROB_TERM_LENGTH) continue;
+		    if (cjk_token.size() > max_word_length) continue;
 
 		    if (stop_mode == STOPWORDS_IGNORE && (*stopper)(cjk_token))
 			continue;
@@ -270,7 +262,7 @@ TermGenerator::Internal::index_text(Utf8Iterator itor, termcount wdf_inc,
 	}
 
 endofterm:
-	if (term.size() > MAX_PROB_TERM_LENGTH) continue;
+	if (term.size() > max_word_length) continue;
 
 	if (stop_mode == STOPWORDS_IGNORE && (*stopper)(term)) continue;
 
